package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````4"(```````!``````````"BQ````
M`````````$``.``-`$``&0`8``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````"`:````````(!H`````````
M$`````````$````%`````"``````````(``````````@````````<3L`````
M``!Q.P`````````0`````````0````0`````8`````````!@`````````&``
M``````"H1@```````*A&`````````!`````````!````!@```/BK````````
M^+L```````#XNP```````"@$````````:!0`````````$`````````(````&
M````"*P````````(O`````````B\````````T`$```````#0`0````````@`
M````````!`````0````X`P```````#@#````````.`,```````!0````````
M`%``````````"``````````$````!````(@#````````B`,```````"(`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````4`````````!0``````````@`````````4.5T9`0`
M``#@GP```````."?````````X)\```````#<`````````-P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````^*L```````#XNP```````/B[````
M````"`0````````(!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````0`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````!``'`!`````D``````````@`!P`0````!````
M``````0````4`````P```$=.50"3+Y%(&PM$20C?T-R+F]K415![=@0````0
M`````0```$=.50``````!`````0``````````````"L```!$````!`````@`
M```@$!``!4`$A"@"``2`A@"$@@D```D@!`B(@!!!N@`""$0`````````````
M`$4``````````````$8``````````````$<`````````2`````````!*````
M``````````!+````3`````````!-````3@```%``````````40```%(```!3
M``````````````````````````````!4````50```%8```!7````6```````
M````````6@````````!;``````````````")!W#3:QJ>4*/@^TGC1\8!9J_,
M9D-%U>R[XY)\LP&+;V_%WQ\5C"7,+L6;MFL)0]8A_^0.^Z%L8,/E/RP-.I<+
MS]Y'+=EQ6!Q_J9R;X:<""D+ZUX=K?YI\,V+;[=1DU'RM2^/`````````````
M````````````````````%@(``!(`````````````````````````K`(``!(`
M````````````````````````C@$``!(`````````````````````````E@(`
M`!(`````````````````````````C````!$`````````````````````````
M_0$``!(`````````````````````````/@$``!(`````````````````````
M````=`(``!(`````````````````````````N0$``!(`````````````````
M`````````0```"``````````````````````````40(``!(`````````````
M````````````9P```!(`````````````````````````D0(``!(`````````
M````````````````E````!(`````````````````````````]@$``!(`````
M````````````````````2`(``!(`````````````````````````G`(``!(`
M````````````````````````T@```!(`````````````````````````X@``
M`!(`````````````````````````,`$``!(`````````````````````````
M9`$``!(`````````````````````````B@```!$`````````````````````
M````;@,``!(`````````````````````````$````"``````````````````
M````````+@(``!(`````````````````````````&P(``!(`````````````
M````````````O0```!(`````````````````````````+````"``````````
M````````````````G0```!(`````````````````````````JP```!(`````
M````````````````````(`(``!(`````````````````````````1@```"(`
M````````````````````````Z````!8`````````````````````````^P``
M`!(`````````````````````````S`$``!(`````````````````````````
M%@$``!(`````````````````````````.0(``!(`````````````````````
M````@@(``!(`````````````````````````HP$``!(`````````````````
M````````10$``!(`````````````````````````)P$``!(`````````````
M````````````5`$``!(`````````````````````````<@$``!(`````````
M````````````````"`(``!(`````````````````````````7`(``!(`````
M````````````````````>0$``!(`````````````````````````S0(``!(`
M````````````````````````>0```!(`````````````````````````AP$`
M`!(`````````````````````````@`$``!(`````````````````````````
MG````!(`````````````````````````G`$``!(`````````````````````
M````N`(``!(`````````````````````````Z@$``!(`````````````````
M````````B0(``!(`````````````````````````V0```!(`````````````
M````````````Q````!(`````````````````````````;0(``!$`````````
M````````````````W0$``!$`````````````````````````I````!(`````
M````````````````````7`$``!(`````````````````````````"P$``!(`
M````````````````````````J@$``!(`````````````````````````50``
M`!(`````````````````````````:P$``!(`````````````````````````
MLP```!(`````````````````````````5@(``!(`````````````````````
M````_P,``!$`%0`8P`````````@`````````4@,``!(`#`!03@```````$L"
M````````"00``!(`#`!P1`````````4%````````_P(``!(`#`!@0P``````
M`"4`````````1@,``!(`#`"00P```````-4`````````V0,``!``%0`@P```
M````````````````QP,``!``%@!@T```````````````````(@,``!(`#`"`
M20```````'T`````````=P,``!(`#`"02P````````X!````````O@,``!(`
M#`!`2P```````$H`````````[@(``!(`#`!`00````````H`````````D@,`
M`!``%0``P```````````````````\@,``!(`#`!000````````4"````````
MX`,``!(`#``P2@```````!`!````````J@,``!(`#``P0````````"H`````
M````E`,``"``%0``P```````````````````S`,``!(`#`"@4````````&4(
M````````L@,``!``%@`@P```````````````````7`,``!(`#```2@``````
M`",`````````,`,``!(`#`!@0````````-@`````````GP,``!(`#`"@3```
M`````*<!````````8@```!(`#``@(````````"("````````F`,``!(`#`!0
M(@```````"8`````````#`,``!(`#``060```````#,"````````@P,``!$`
M#@``8`````````0``````````%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I
M<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%]?
M8WAA7V9I;F%L:7IE`%]?;&EB8U]S=&%R=%]M86EN`%]?<F5G:7-T97)?871F
M;W)K`%]?<W1A8VM?8VAK7V9A:6P`7U]E;G9I<F]N`'-T<FYC;7``;'-T870V
M-`!A8V-E<W,`;W!E;F1I<@!R96%D9&ER-C0`<W1R;&5N`%]?<W!R:6YT9E]C
M:&L`=6YL:6YK`&-L;W-E9&ER`')M9&ER`%!,7V-U<G)E;G1?8V]N=&5X=`!B
M;V]T7T1Y;F%,;V%D97(`4&5R;%]N97=84P!097)L7VYE=UA37V9L86=S`')E
M861L:6YK`%!E<FQ?<W9?<V5T<'8`;65M8VAR`%!E<FQ?<W9?<V5T<'9N`&UE
M;6UO=F4`<F5A;&QO8P!G971P:60`;65M8W!Y`'-T<F-H<@!S=')D=7``<W1R
M=&]K`'-T<F-M<`!?7W-T<FYC<'E?8VAK`&=E='5I9`!S=')S='(`4&5R;%]S
M>7-?:6YI=#,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`
M4$Q?9&]?=6YD=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E
M<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO
M8P!P97)L7V-O;G-T<G5C=`!P97)L7W)U;@!E>&ET`&UK9&ER`%]?97)R;F]?
M;&]C871I;VX`<W1D97)R`%]?9G!R:6YT9E]C:&L`;W!E;C8T`&QS965K-C0`
M<F5A9`!C;&]S90!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%]M9U]S970`;&EB<&5R;"YS;P!L:6)C+G-O
M+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS
M7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`
M<VAA7W5P9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`
M<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN
M9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$T`$=,24)#
M7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?
M,BXR+C4`1TQ)0D-?,BXS+C0`+W5S<B]L:6(O<&5R;#4O-2XS-B]C;W)E7W!E
M<FPO0T]210````$``0`"``,``P`!``,``@`!``$``P`$``,``P`#``$``0`#
M``,``0`#``,``P`!``$``P`#``$`!0`#``$``P`!``$``0`!``$``P`#``$`
M`P`#``,``0`#``,``0`&``,``P`%``,``0`!``,``P`"``,``0`#``,``0`!
M``<`"``#``,``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`````````!``<`Y`(``!``````````E)&6!@``"``6
M!```$````+21E@8```<`(00``!`````4:6D-```&`"P$```0````LY&6!@``
M!0`V!```$````'(9:0D```0`000``!````!U&FD)```#`$T$```0````=!EI
M"0```@!9!````````/B[````````"`````````!`(P````````"\````````
M"`````````#P(@````````C`````````"``````````(P````````!C`````
M````"`````````#88@```````/"]````````!@````$``````````````/B]
M````````!@````(```````````````"^````````!@````,`````````````
M``B^````````!@````0``````````````!"^````````!@````4`````````
M`````!B^````````!@````8``````````````""^````````!@````<`````
M`````````"B^````````!@````@``````````````#"^````````!@````D`
M`````````````#B^````````!@````H``````````````$"^````````!@``
M``L``````````````$B^````````!@````P``````````````%"^````````
M!@````T``````````````%B^````````!@````X``````````````&"^````
M````!@````\``````````````&B^````````!@```!```````````````'"^
M````````!@```!$``````````````'B^````````!@```!(`````````````
M`("^````````!@```!,``````````````(B^````````!@```!0`````````
M`````)"^````````!@```!4``````````````)B^````````!@```!<`````
M`````````*"^````````!@```!@``````````````*B^````````!@```!D`
M`````````````+"^````````!@```!H``````````````+B^````````!@``
M`!L``````````````,"^````````!@```!P``````````````,B^````````
M!@```!T``````````````-"^````````!@```!X``````````````-B^````
M````!@```!\``````````````."^````````!@```"```````````````.B^
M````````$@```"$``````````````/"^````````!@```"(`````````````
M`/B^````````!@```",```````````````"_````````!@```"0`````````
M``````B_````````!@```"4``````````````!"_````````!@```"8`````
M`````````!B_````````!@```"<``````````````""_````````!@```"@`
M`````````````"B_````````!@```"D``````````````#"_````````!@``
M`"H``````````````#B_````````!@```"L``````````````$"_````````
M!@```"P``````````````$B_````````!@```"T``````````````%"_````
M````!@```"X``````````````%B_````````!@```"\``````````````&"_
M````````!@```#```````````````&B_````````!@```#$`````````````
M`'"_````````!@```#(``````````````'B_````````!@```#,`````````
M`````("_````````!@```#0``````````````(B_````````!@```#4`````
M`````````)"_````````!@```#8``````````````)B_````````!@```#<`
M`````````````*"_````````!@```#@``````````````*B_````````!@``
M`#D``````````````+"_````````!@```#H``````````````+B_````````
M!@```#L``````````````,"_````````!@```#P``````````````,B_````
M````!@```#T``````````````-"_````````!@```#X``````````````-B_
M````````!@```#\``````````````."_````````!@```$``````````````
M`.B_````````!@```$$``````````````/"_````````!@```$(`````````
M`````/B_````````!@```$,`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!2F>``!(A<!T`O_02(/$",,``````/,/'OI54TB#[#B)
M?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E*````$B)1"0H,<#_
M%7N?``!(BS7,G0``2(L]C9X``$B)\F?HW#H``$B+!3V?``"`.``/A"(!``!(
MBP5=G@``9$B+`("(*@0```.+1"0<C7@$C5@#2&/_2,'G`_\5XYX``$B+3"00
M1(M$)!Q(B<9(B067GP``2(L!2(D&2(T%94```$B)1@A(C04_GP``2(L`2(E&
M$$B-!4]```!(B48808/X`0^.,@$``$B#P0A!@\`#N`0```!F#Q]$``!(BSE(
M8]"#P`%(@\$(2(D\UD0YP'7J2)A(B?&)VDB+/1R?``!(QP3&`````$4QP$B-
M-6(;``#_%=2<``")PX7`#X2*````2(UL)"1(BSWNG@``_Q7@G0``,<!(B>Y(
MC3TW/P``Z$\8``!(A<!T=DB+/<N>``#_%6V<``#_%4^=``!(BT0D*&1(*P0E
M*`````^%GP```$B#Q#B)V%M=P_\5_)P``$B)!96>``!(B<=(A<!T=O\51YT`
M`$B+!2"=``!D2(L0QH+7"0```.FS_O__2(L]:9X``/\5@YP``(G#Z6+___](
MBSU=G@``2(7_=`MGZ)(I``#I<____TB-/4X^``!(B>[HKA<``$B)!3>>``!(
MB<=(A<`/A%'____KT;@$````Z>W^__^_`0```/\5!)P``/\5'IT``&8N#Q^$
M```````/'T``\P\>^C'M28G17DB)XDB#Y/!05$4QP#')2(T]L?W___\5:YT`
M`/1F+@\?A```````2(T]F9T``$B-!9*=``!(.?AT%4B+!0:<``!(A<!T"?_@
M#Q^``````,,/'X``````2(T]:9T``$B--6*=``!(*?Y(B?!(P>X_2,'X`T@!
MQDC1_G042(L%Y9L``$B%P'0(_^!F#Q]$``###Q^``````/,/'OJ`/26=````
M=3-52(,]VIL```!(B>5T#4B+/?:<``#_%<B;``#H8____\8%_)P```%=PV8N
M#Q^$``````##9F8N#Q^$```````/'T``\P\>^NEG____#Q^``````$%72(G^
M3(U'.$%6055!5%532('LF`(``&1(BP0E*````$B)A"2(`@``,<!(B>),C8PD
M@````$B)UP\?@`````!!BP!-BQ!(@\<028/`"`_(B<!,B=%(B4?P3(G02,'I
M($C!Z"A)P>HX)0#_``!,"=!)B<I(P>$(2<'B&('A``#_`$6)TDP)T$@)R$B)
M1_A,.<]UK68/;T0D$&8/;UPD($B-1"1H2('":`(``&8/;U0D,&8/;RV7>P``
M#Q^``````/,/;PAF#V_B9@]O4-A(@\`09@_O0(AF#^_*9@_OP68/;\AF#W/0
M'V8/<_$!9@_KP68/V\4/*4`(9@]OPV8/;]Q(.=!UNTR+#DR+7A!(BWX@2(M>
M&$R)R$R)RDB+;@A(BTPD"$C!ZAM(P>`%2`G0`P0D2(V,"YEY@EJ-E#B9>8):
M3(G82#'82"'H2#'8C3P"2(GJ2(GH2,'H`DC!XAY)B?I("<),B=A)P>H;08G0
M3#'`3"'(3#'82`'(2(GY2,'A!4P)T4R+5"001(TD"$R)R$R)R4C!Z0)(P>`>
M3XV4$YEY@EI-B>5("<A)P>T;2#'"B<%((?I,,<),`=)-B>))P>(%30GJ3(ML
M)!A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G52#'0B==,(>!)P>T;
M2#'(3`'`38G02<'@!4T)Z$R+;"0@00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"
M6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%3`GI3(ML)"@!T4R)
MTDG!Z@)(P>(>B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!B=),(<!,,>!(`?A(
MB<](P><%3`GO3(ML)#`!QTR)P$G!Z`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@Q
MPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL3(ML)#A!`=1(B<I(P>D"2,'B
M'D6)Y$^-E"J9>8):2`G*38GE2#'02<'M&XG12"'X3#'`3`'038GB2<'B!4T)
MZDR+;"1`00'"2(GX2,'O`DC!X!Y%B=)/C80HF7F"6D@)^$V)U4@QPDG![1N)
MQTPAXD@QRDP!PDV)T$G!X`5-">A,BVPD2$$!T$R)XDG![`)(P>(>18G`2HV,
M*9EY@EI,">)-B<5(,=!)P>T;08G43"'02#'X2`'(3(G!2,'A!4P)Z4R+;"10
M`<%,B=!)P>H"2,'@'HG)2HV\+YEY@EI,"=!)B<U(,<))P>T;08G"3"'"3#'B
M2`'Z2(G/2,'G!4P)[TR+;"18`==,B<))P>@"2,'B'HG_3XVD+)EY@EI,"<))
MB?U(,=!)P>T;08G02"'(3#'03`'@28G\2<'D!4T)[$R+;"1@00'$2(G(2,'@
M'DC!Z0)%B>1/C90JF7F"6D@)R$V)Y4@QPDG![1N)P4@A^DPQPDP!TDV)XDG!
MX@5-">I,BVPD:$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=!)
MP>T;B==,(>!(,<A,`<!-B=!)P>`%30GH3(ML)'!!`<!,B>!)P>P"2,'@'D6)
MP$J-C"F9>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,
MBVPD>`'13(G22,'B'DG!Z@*)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPA
MP$PQX$@!^$B)STC!YP5,">],BZPD@`````''3(G`2<'H`DC!X!Z)_T^-I"R9
M>8):3`G`28G]2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q&C2PB2(G*
M2,'I`DR+I"2(````2,'B'D@)RD^-E"*9>8):38GL2#'02<'L&XG12"'X3#'`
M3`'038GJ2<'B!4T)XDR+I"20````00'"2(GX2,'@'DC![P)%B=)/C80@F7F"
M6D@)^$V)U$@QPDG![!N)QTPAZD@QRDP!PDV)T$G!X`5-">!%B<!,`<)-B>A)
MP>T"2<'@'D&)U$T)Z$R+K"28````3#'`3"'02HV,*9EY@EI-B>5(,?A)P>T;
M2`'(3(GA2,'A!4P)Z8G)2`'(3(G12<'J`DC!X1Y!B<5,"=%-B<)%B<!),<I$
M,=),BY0DH````$J-O!>AZ]EN38GJ2`'73(GJ2<'J&TC!X@5,"=*)TD@!UTR)
MXDC!XAY)P>P"08GZ3`.$)*@```!,">))B<R)R4@#C"2P````23'41#'@38VD
M`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$3(GH2<'M`DC!X!Y%B>!,">A)
MB=6)TD@#E"2X````23'%1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)
M20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ
M2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(2`.$),````")
MR4DQT$@#C"3(````13'H3HVL`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'%
M2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"30````2#''1#'G3(VD.:'KV6Y,
MB<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#
MA"38````23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"
M2<'H`DC!XAY%B>I,"<))B<B)R4DQT$@#C"3@````13'@3HVD`*'KV6Y,B=!-
MB=!)P>@;2,'@!4P)P(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"3H
M````2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J
M`DC!X1Y$B>],"=%)B<*)P$@#A"3P````23'*13'B3HVD$J'KV6Y(B?I)B?I)
MP>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-
MK`"AZ]EN3(G038G02,'@!4G!Z!M(`XPD^````$P)P(G`20'%2(GX2,'O`DC!
MX!Y%B>A("?A(B=>)TD@#E"0``0``2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;
M2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#A"0(`0``23'*
M13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"2<'H`DC!XAY%
MB>I,"<))B<B)R4DQT$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,"<!(`XPD
M$`$``(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"08`0``2#''1#'O
M3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],
M"=%)B<*)P$@#A"0@`0``23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)
MTHG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G0
M38G02<'H&TC!X`5,"<")P$D!Q4B)^$C!X!Y(P>\"18GH2`.,)"@!``!("?A(
MB=>)TD@#E"0P`0``2#''1#'G38G$2(V,.:'KV6Y,B<=)P>P;2,'G!4P)YTV)
MU$G!Z@))P>0>B?]-"=1)B<)(`?F)P$TQXHG/2`.$)#@!``!%,>I)B?U.C902
MH>O9;DB)^DG![1M(P>(%3`GJ00'23(G"2<'H`DC!XAY%B=),"<)-B>!%B>1)
M,=!)B=9!B=5$,<%-B=!(C8P(H>O9;DR)T$G!Z!M(P>`%3`G`1(T$`4B)^4C!
M[P*XW+P;CTC!X1Y("?E)"<Z)ST@A^DTAUDD)UDB+E"1``0``2`'"3`'B38G$
M3`'R38G&2<'D!4G![AM-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)
MTDDA_DPAP4P)\4R+M"1(`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-"?5)
MB=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"10`0``
M20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],">)(
M"=%)B=9!B=1-(<9,(>E,"?%,B[0D6`$``$D!QDT!\DF)_DP!T4F)^DG![AM)
MP>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),
MB[0D8`$``$D!QDT!\$V)UDP!PDV)T$G!X`5)P>X;30GP00'02(GZ2,'O`DC!
MXAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"1H`0``20'&30'T38G&3`'A
M38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4&)RDD)SDTA
MQDPATDP)\DR+M"1P`0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,
MB<)(P>(>2<'H`D6)[4P)PD@)T4F)UD&)T$TAUDPAX4P)\4R+M"1X`0``20'&
M3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?=)B=8!STR)X4G![`)(P>$>B?],">%!
MB<Q)"<Y-(>Y,(>),"?),B[0D@`$``$D!QDT!\DF)_DP!TDF)^DG![AM)P>(%
M30GR00'23(GJ2<'M`DC!XAY%B=),">I("=%)B=9!B=5((?E-(>9,"?%,B[0D
MB`$``$D!QDT!\$V)UDP!P4V)T$G![AM)P>`%30GP28G600'(2(GY2,'O`DC!
MX1Y%B<!("?F)STD)SDTAUD@A^DP)\DR+M"20`0``20'&30'T38G&3`'B38G$
M2<'N&TG!Y`5-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPA
MP4P)\4R+M"28`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,
MB<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"2@`0``20'&3`'W
M38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],">)("=%)B=9!
MB=1-(<9,(>E,"?%,B[0DJ`$``$D!QDT!\DF)_DP!T4F)^DG![AM)P>(%30GR
M28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),B[0DL`$`
M`$D!QDT!\$V)UDP!PDV)T$G![AM)P>`%30GP00'02(GZ2,'O`DC!XAY%B<!(
M"?I("=%)B=:)UTTA[DPAT4P)\4R+M"2X`0``20'&30'T38G&3`'A38G$2<'N
M&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4D)SD&)RDTAQDPATDP)
M\DR+M"3``0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,B<))P>@"
M2,'B'D6)[4P)PD@)T4F)T$&)UTTAT$PAX4P)P4R+A"3(`0``20'`3`''38GH
M2`'Y3(GO2<'H&TC!YP5,"<=$C00Y3(GG2<'L`DB)T4C!YQY,">=!B?Q("?E,
M(>E,(>)("<I(BXPDT`$``$@!P4P!T4V)PD@#A"38`0``2`'*3(G!2<'J&TC!
MX05,"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI2`G/28G-08G.3"''32'E20G]
M2HT\.$R)T$R+O"3X`0``3`'O38G52,'@!4G![1M,">B)P$@!QTR)P$G!Z`)(
MP>`>08G]20G`N-;!8LI,,<$QT4B+E"3@`0``2`'"3`'B38GL2`'*3(GI2<'L
M&TC!X05,">%-B=2)R4G!Y!Y(`<I)P>H"20''30GB38G$B=%%B<!-,=1$,>=,
MBZ0DZ`$``$D!Q$T!]$F)SDP!YTF)S$G![AM)P>0%30GT38GN2<'M`DG!YAY%
MB>1-"?5,B[0D\`$``$P!YT&)_$D!QDT!\$V)UDTQ[D0Q\DV)YDD!T$R)XDG!
M[AM(P>(%3`GRB=))`=!(B<I(P>D"2,'B'D6)QD@)RD2)T4V)ZDDQTDP!^4R+
MO"0``@``1#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(
MP>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD$`(``$4QZ$V)U4D!R$R)T4G!
M[1M)`<=(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"0(`@``20'&
M3`'R38GF23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(
MP>(>08G^20G21(GB28G,B<E,`?I-,=1,B[PD(`(``$4QX$V)]$D!T$R)\DG!
M[!M)`<=(P>(%3`GBB=))`=!,B>I)P>T"2,'B'D6)Q$P)ZDR+K"08`@``20'%
M3`'I38G523'51#'O38GE2`'/3(GA2<'M&TC!X05,">F)R4@!STR)\4G![@)(
MP>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD,`(``$4QT$V)ZDD!R$R)Z4G!
MZAM(P>$%3`G1B<E)`<A,B>%(P>$>2<'L`D6)PDD!QTP)X4R+I"0H`@``20'$
M3`'B38GT23',1#'G38G42`'73(G22<'L&TC!X@5,">*)TD@!UTR)ZDG![0)(
MP>(>08G\20G51(GR28G.B<E-,>Y,`?I,B[PD0`(``$4Q\$V)YDD!T$R)XDG!
M[AM(P>(%3`GRB=))`=!,B=))P>H"2,'B'D6)QDP)TDR+E"0X`@``20'"3`'1
M38GJ23'21#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(
MP>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD8`(``$4QZ$V)U4D!R$R)T4G!
M[1M(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"1(`@``20'&3`'R
M38GF18GD23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(
MP>(>08G^20G22(N4)%`"``!(`<))`=1(B<J)R4PQTDD!QT0QPDV)\$D!U$R)
M\DG!Z!M(P>(%3`G"B=))`=1,B>I)P>T"2,'B'D6)X$P)ZDR+K"18`@``20'%
M3`'I38G523'51#'O38G%2`'/3(G!2<'M&TC!X05,">F)R4@!STR)\4G![@)(
MP>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD<`(``$4QXDV)[$P!T4V)ZDG!
M[!M)P>(%30GB38G$18G22<'D'DP!T4G!Z`))`<=-">!,BZ0D:`(``$&)RDD!
MQ$@#A"1X`@``3`'B38GT3`'(33'$1#'G38G42`'73(G22<'L&TC!X@5,">)-
MB>Q)P>T"2<'D'HG230GE18GT38G&2`'733'NB?I-`?Q%B<!$,?%)B=9,`<!-
MB>A,`>%)B=1)P>X;2<'D!4T)]$0!X4V)U$G!Z@))P>0>B<E-">)-,=!$,<=)
MB<A(`?A(B<](P><%2<'H&P'I00':3`G'1`-N($B)3@@!^$R)5AA(B09(B=!(
MP>H"2,'@'DR);B!("=!$`=A(B4802(N$)(@"``!D2"L$)2@```!U$DB!Q)@"
M``!;74%<05U!7D%?P_\5I84```\?1```05=!5D%505154TB#[`A(A?\/A+$`
M``!(BP4RA```3(LP387V#X2>````#[8'28G_28GUA,!T!#P]=55%,>1)BQY(
MA=MT,4UCY$R)]0\?0`!,B>),B?Y(B=__%3F$``"%P'4'0H`\(SUT1DB+70A(
M@\4(2(7;==E(@\0(2(G86UU!7$%=05Y!7\,/'X``````28G\00^V1"0!28/$
M`83`=`0\/77N12G\ZY1F#Q]$``!,*?5*C5PC`4C!_0-!B6T`Z[5F#Q]$```Q
MV^NK#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$))@````QP$B)YO\5P80`
M`(7`=36+5"08@>(`\```@?H`0```=`B!^@"@``!U';X"````2(G?_Q7=A```
MA<`/E,`/ML#K!0\?`#'`2(N4))@```!D2"L4)2@```!U"4B!Q*````!;P_\5
M3(0``&9F+@\?A```````D$%505154TB![*@```!D2(L$)2@```!(B80DF```
M`#'`2(7_=`B`/P!(B?MU*TB+A"28````9$@K!"4H````#X4S`0``2('$J```
M`%M=05Q!7<-F#Q]$``#_%5*#``!(B<5(A<!TQTB)[_\5880``$B%P`^$N```
M`(!X$RY,C6`3=0Y!@'PD`0!TW&8/'T0``(!X$RX/A+8```!(B=__%?6"``!,
MB>=)B<7_%>F"``!!C7P%`DAC__\5@X(``$V)X4F)V+X!````28G%2(G',<!(
MQ\+_____2(T-!B0``/\5I(,``$R)[TB)YO\5N((``$R)[X/X_W00BT0D&"4`
M\```/0!```!T:/\52H(``$R)[_\5>8(``$B)[_\5L(,``$B%P`^%3____P\?
M@`````!(B>__%4>#``!(B=__%1Z"``#IYO[__V8/'X0``````$&`?"0!+@^%
M/O___T&`?"0"``^$_O[__^DM____#Q\`Z(O^___KE_\5PX(```\?`/,/'OI3
M2(L=/((``$B-#=5B``!(C350(P``2(L5+X(``&1(BSO_%06#``!,C074)```
M9$B+.T4QR4B-%3`<``!,B<%(C34\(P``6_\E#X(``&9F+@\?A```````#Q]`
M`$%505154TB![``0``!(@PPD`$B#[!BZ_P\``&1(BP0E*````$B)A"0($```
M,<!)B>1(B?M(B?5(C3W](@``3(GF_Q7A@0``A<!^$HG!@^@!2&/0@#P4`'5'
MA<!U.TB+!82!``!(B>I(B=YD2(LX_Q44@0``2(N$)`@0``!D2"L$)2@```!U
M3DB!Q!@0``!;74%<05W##Q\`B<%F#Q]$``!,8^F^+P```$R)YTR)ZO\5;(``
M`$B%P'2D2(L%*($``$R)Z4R)XDB)WF1(BSC_%4V!``#KG_\5A8$```\?1```
M05=!5D%505152(GU4TB)^TB#["AD2(L$)2@```!(B40D&#'`,<"`/CT/E,!(
M`<5(B>__%:"```!(C70D%$B)WTF)Q#'`Z);[__](A<`/A`T!``!)B<5(B<?_
M%7F```!,.>`/@]@```!(8TPD%$R+-;Q_``!,C3S-``````^V`X3`#X2A`0``
M/#T/A)D!``!(B=AF#Q]$```/ME`!2(/``832=`6`^CUU[T@IV$B838LN2HU\
M(`+_%<1_``!-`?U)B44`2(7`=%%)BP9(C4L!2HL4.`^V`X@"A,!T(3P]=0SK
M&V8/'T0``(3`=!$/M@%(@\(!2(/!`8@"/#UUZ\8"/3'`9@\?1```#[9,!0"(
M3`(!2(/``83)=>](BT0D&&1(*P0E*`````^%#P$``$B#Q"A;74%<05U!7D%?
MPP\?0``QP&8/'T0```^V5`4`08A4!0!(@\`!A-)U[NN]#Q]``$R+-<E^``!-
MBP9)@S@`#X2[````3(G`13'M9@\?1```2(/`"$2)ZD&#Q0%(@S@`=>^-<@-(
M8_9(P>8#BP6_@```A<!U6TB)]TR)1"0(QP6I@````0```/\5PWX``$B)QTB%
MP`^$4/___TECS4B+="0(3(T\S0````!,B?K_%6Y_``!)B09(B<=!C44!1(EL
M)!1(F$C'!,<`````Z7S^__],B<?_%=]_``!)B09(B<=(A<`/A`'___])8\U,
MC3S-`````.O##Q\`,<#I?_[__[X0````13'MZ5______%3Y_``!F9BX/'X0`
M``````\?`/,/'OI(BP6M?@``2(L5KGX``$B-#3]?``!(C36Z'P``9$B+./\E
M=G\``&8/'T0``/,/'OI54TB![``0``!(@PPD`$B![``0``!(@PPD`$B#["AD
M2(L$)2@```!(B80D&"```#'`2(V<)!`0``!(B>7_%>I]``"Z`1```$B)W[X!
M````08G`3(T-B1\``#'`2(T-A!\``/\5W'X``+H`$```2(GN2(G?_Q5+?@``
MA<!X4XUX`4B)PTAC__\5<'T``$B%P'0_2&/;2(GN2(G'2(G:_Q7A?@``Q@08
M`$B)P4B+A"08(```9$@K!"4H````=0U(@<0H(```2(G(6UW#_Q4L?@``,<GK
MU@\?A```````\P\>^ND7____D&8/'T0``/,/'OI!5T%6055!5%532('L`!``
M`$B##"0`2('LN````&1(BP0E*````$B)A"2H$```,<!)B?Q(B?5(C3W''@``
M2(UT)`SH)?C__[XO````3(GG2(G#_Q6,?0``2(7`=#\QP$R)YDB-/:0>``#H
M'OS__TR)X$B+E"2H$```9$@K%"4H````#X5S`0``2('$N!```%M=05Q!74%>
M05_#9I!,B>=,C2UT'@``_Q6X?```2(GO08G&_Q5$?0``3(GN2(G'_Q58?0``
M28G'2(7`=)%!@\8!08`_``^$Q0```&:02(7;=!1,B?Y(B=__%2=]``"%P`^$
MB0```$R)__\59GP``.L'#Q]``,8"`(G!@^@!2&/03`'Z@#HO=.U$`?&!^?\/
M```/CS?___^Z`!```$V)^+X!````,<!(C:PDH````$B#[`A(C0W*'@``051,
MC0W+'0``2(GO_Q7Z?```2(GO2(UT)"#_%0Q\``!:687`=1"+1"0H)0#P```]
M`(```'1.3(GN,?__%9-\``!)B<=(A<`/A,C^__]!@#\`#X4]____2(7;=`6`
M.RYT$TR-/5(=``"Y`0```.E=____9I"`>P$`=+SKY0\?A```````O@$```!(
MB>__%9)\``"%P'6@2(GN2(T])1T``.B?^O__2(GO_Q4&?```Z7;^____%0M\
M``!F9BX/'X0``````/,/'OH/M@=(B?J$P'039I!(@\<!/"\/M@=(#T37A,!U
M[TB)T,-F9BX/'X0``````/,/'OI(A?\/A+L```!3@#\`2(G[#X2&````_Q4(
M>P``2(U4`_](.=-R#^LJ#Q]``$B#Z@%(.=-T=X`Z+W3R2#G3<@[K$0\?`$B#
MZ@%(.=-T7X`Z+W7R2#G3=0KK4P\?`(`Z+W4)2(/J`4@YTW+R2"G:,<!(C4H"
M2('Y`!```'<92(/"`;D`$```2(G>2(T]/7P``/\5UWD``%O##Q]$``!(C3T?
M'```6_\E$GL``&:0@#LO=.M(C3TD'```6_\E_7H```\?1```2(T]]QL``/\E
MZWH``&9F+@\?A```````\P\>^D%7059!54%454B-+>X;``!32(/L&&1(BP0E
M*````$B)1"0(,<!(C5PD!&:0,<!(B=Y(B>_H$_7__TB%P'0^2(L%5WD``$AC
M5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7P
MZ[9F#Q]$``!(C2V$&P``9@\?A```````,<!(B=Y(B>_HL_3__TB%P'0^2(L%
M]W@``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)
M$$B%TG7PZ[9F#Q]$``!(C2TL&P``9@\?A```````,<!(B=Y(B>_H4_3__TB%
MP'0^2(L%EW@``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`0
M2(/`"$B)$$B%TG7PZ[9F#Q]$``!(C2W5&@``9@\?A```````,<!(B=Y(B>_H
M\_/__TB%P'0^2(L%-W@``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@```
M``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C2U\&@``9@\?A```````,<!(
MB=Y(B>_HD_/__TB%P'0^2(L%UW<``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)T
MSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,C24L&@``9@\?A```
M````,<!(B=Y,B>?H,_/__TB%P'0^2(L%=W<``$AC5"0$2(L`2(T$T$B+4`A(
MB1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,C26!&0``
M9@\?A```````,<!(B=Y,B>?HT_+__TB%P'0^2(L%%W<``$AC5"0$2(L`2(T$
MT$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,
MC35X&0``9@\?A```````,<!(B=Y,B??H<_+__TB%P'0^2(L%MW8``$AC5"0$
M2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F
M#Q]$``!,C2TB&0``9@\?A```````,<!(B=Y,B>_H$_+__TB%P'0^2(L%5W8`
M`$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%
MTG7PZ[9F#Q]$``!,C3W,&```9@\?A```````,<!(B=Y,B?_HL_'__TB%P'0^
M2(L%]W4``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`
M"$B)$$B%TG7PZ[9F#Q]$``!,C3T*&```9@\?A```````,<!(B=Y,B?_H4_'_
M_TB%P'0^2(L%EW4``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(
MBU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(B=Y(C3T3&```Z`'Q__](A<!T#4B)
MQDR)[S'`Z`_U__\QP$B)WDB-/0$8``#HWO#__TB%P'012(G&2(T]_Q<``#'`
MZ.CT__](B=Y(C3WY%P``,<#HM_#__TB)QDB%P'0Y3(GG,<#HQ?3__TB+1"0(
M9$@K!"4H````=41(@\082(GO2(TUXQ<``#'`6UU!7$%=05Y!7^F6]/__,<!(
MB=Y(C3VU%P``Z&7P__](A<!TNTB)QDR)]S'`Z'/T___KK/\5ZW4``&9F+@\?
MA```````\P\>^DB#[!AD2(L$)2@```!(B40D"(L%='8``(/X_W0?2(M4)`AD
M2"L4)2@```!U1DB#Q!C#9BX/'X0``````$B-="0$2(T]XQ8``#'`Z.WO__](
MB<(QP$B%TG02#[8"/#`/E<*$P`^5P`^VP"'0B04;=@``ZZK_%6-U```/'P#S
M#Q[Z2(/L"/\5<G4``(G'_Q6"=```2(7`=`-(BP!(@\0(PV9F+@\?A```````
M9I#S#Q[Z055!5$R-)=\6``!52(G]3(GG4TB#[!AD2(L$)2@```!(B40D"#'`
M2(UT)`3H6^___TB%P'0(@#@`2(G#=2Y(BT0D"&1(*P0E*`````^%M````$B)
M[DB#Q!A,B><QP%M=05Q!7>E#\___#Q\`2(GN2(G'_Q5L=```2(7`=!](BT0D
M"&1(*P0E*````'5Y2(/$&%M=05Q!7<,/'T``2(GO_Q7?<P``2(G?28G%_Q73
M<P``28U\!0+_%7!S``!(@^P(28GHO@$```!32,?"_____TB)QTF)Q4R-#5T5
M``!(C0U.%@``,<#_%8AT``!86DB+1"0(9$@K!"4H````=0A,B>[I3_____\5
M('0``/,/'OI(@^P(OX````#_%0US``!F#V\%550``$C'0#``````#Q$`9@]O
M!5)4``#'0'@`````#Q%`$&8/;P5/5```#Q%`($B#Q`C#9@\?1```\P\>^D%4
M54B)_5-(@^P09$B+!"4H````2(E$)`@QP&?HV_?__P^V$$B)PX32=!.02(/`
M`8#Z+P^V$$@/1-B$TG7NBP4X=```2(7M00^5Q(/X_W1LA<`/E<!!(<1%A.1U
M'TB+1"0(9$@K!"4H````#X63````2(/$$%M=05S#9I"`?0``=-NZ!````$B-
M-0P5``!(B=__%2UR``"%P'7"2(M$)`AD2"L$)2@```!U64B#Q!!(B>];74%<
MZ='N__^0,<!(C70D!$B-/5$4``#H7>W__TB%P'0A#[80A-(/E<"`^C`/E<(A
MT$$AQ`^VP(D%C',``.EC____QP5]<P```````.E9_____Q7"<@``9I#S#Q[Z
M05=(8\)!5DF)QD%5051)B?Q52(UO.%-(B?-(@^P(2(MW*$B+5S"-#,9(.?%(
MB4\H2(/2`$C!Z!U(`=!(B4<P2&-'>(7`#X7I````08/^/P^.+P$``$&#[D!%
MB?=!P>\&18UO`4G!Y09)`=V0\P]O`TR)YTB#PT`/$44`\P]O2]`/$4T0\P]O
M4^`/$54@\P]O6_`/$5TPZ!'6__],.>MUS$'!YP9%*?Y)8\9(@_@(<EQ)BU4`
M2(U-"$B#X?A)B50D.$F+5`7X2(E4!?A(*<U(`>A)*>U(@^#X2(/X"'(82(/@
M^#'228MT%0!(B3012(/""$@YPG+N18ET)'A(@\0(6UU!7$%=05Y!7\-FD*@$
M=7Q(A<!TX4$/ME4`08A4)#BH`G3300^W5`7^9HE4!?[KQ@\?0`!!OT````!(
MC7P%`$B)WD$IQT4Y]T4/3_Y-8^],B>K_%>QQ``!!BT0D>$0!^$&)1"1X@_A`
M=9%,B>=%*?Y,`>OH--7__^G._O__#Q^``````$F)W>D;____08M5`$&)5"0X
M08M4!?R)5`7\Z5/___]F#Q^$``````#S#Q[Z059,C78X055!5%5(B?U33(MN
M*$B)\TR+9C!,B>A(P>@#@^`_C4@!2)C&1`8X@$ACP4P!\(/Y.`^.?P$``+Y`
M````*<YT#S'2B=&#P@'&!`@`.?)R\TB)W^B?U/__9@_OP`\10SA)QT8P````
M`$$/$48000\11B!,B>)!#[;%3(GO3(GN2,'J&$C!X`A,B>%(P>\028G03(GJ
M2,'N&`^VUD`/MO]`#[;V2,'I$$@)T$R)X@^VR4C!X`A("?@/MOY!#[;02,'@
M"$@)\$$/MO1(P>`(2`GP2,'@"$@)^$B)WTC!X`A("<A(P>`(2`G02(E#<.@&
MU/__2(L#2(G?2,'H&(A%`$B+`TC!Z!"(10%(BP.(90)(BP.(10-(BT,(2,'H
M&(A%!$B+0PA(P>@0B$4%2(M#"(AE!DB+0PB(10=(BT,02,'H&(A%"$B+0Q!(
MP>@0B$4)2(M#$(AE"DB+0Q"(10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#
M&(AE#DB+0QB(10](BT,@2,'H&(A%$$B+0R!(P>@0B$412(M#((AE$DB+0R"(
M11-;74%<05U!7O\EI6X```\?1```NC@````Q_RG*@_H(<D*)T4C'``````!(
MQT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(#X*"_O__@^+X,<")QH/`"$B)
M/#$YT'+SZ6O^___VP@1U(X72#X1>_O__Q@``]L("#X12_O__,<EFB4P0_NE&
M_O__#Q\`QP``````QT00_`````#I,/[__P\?1```\P\>^D%7059!54%455-,
MC9PD`(#__TB![``0``!(@PPD`$PYW'7O2('L6`$``$B-#6L0``!(C14J$```
M9D@/;L%(C0T!$```9$B+!"4H````2(F$)$B!``!(C056#P``2(U<)!Q)B?Y(
MC3U)#P``2,=$)%``````2(G>2,>$)(@`````````2,=$)#``````9D@/;LA(
MC04)$```9@]LP69(#V[02(T%`1````\I1"1`9D@/;L%F2`]NV$B-#>\/``!F
M#VS"2(T%Z0\```\11"1H9D@/;L)F2`]NX#'`9@]LPP\11"1X9D@/;L%F#VS$
M#RE$)"#H)NC__TB%P'0,@#@`2(G%#X5]!```_Q7/;0``B<?_%=]L``!(A<`/
MA.X#``!,BRA-A>T/A.(#``!,B>__%>%L``!(C7P``?\5?FP``$4/MD4`28G'
M28G$183`=#Y(C2UF#P``#Q^``````$F#Q0%%#[;`3(G_2(GI2,?"_____[X!
M````,<!)@\<"_Q6";0``10^V10!%A,!UT$R-;"1@2(T]M`X``.L/9I!)BWT(
M28/%"$B%_W0[2(G>,<#H:>?__TB)Q4B%P'3A@#@`=-Q(B<?H).C__X7`=-!(
MB>__%==L``!(B<5(A<!U/P\?@`````!,C6PD0$F+;0!(A>UT*H!]```/A``#
M``!(B>_HZ.?__X7`#X40`0``28MM"$F#Q0A(A>UUV0\?`$B)[_\5[VL``$R)
MYTF)Q?\5XVL``$&-A`4$!```3&/X3(G__Q5W:P``051)B>B^`0```$F)Q4B-
M!3$.``!,C0UL#0``2,?"_____U!(C0U1#@``3(GO,<#_%8IL``!,B>^^P`$`
M`/\5S&P``%]!6(/X_W43_Q4.;```1(L(08/Y$0^%M`(``$B-A"20````3(GO
M2(D$)$B)QO\5&6P``(G%A<!T>TB+!41L``!)BPY-B>A(C167#@``O@$```!(
MBS@QP/\5GVH``$4QY$B+A"1(@0``9$@K!"4H````#X5<!0``2('$6($``$R)
MX%M=05Q!74%>05_##Q^$``````!(B>])@\4(_Q6#:P``2(G%2(7`#X2T_O__
MZ>+^__]FD(N$)*@````E`/```#T`0```#X5N____1(ND)*P```#_%7MK``!!
M.<0/A5?___^+A"2H````)?\!```]P`$```^%0/___TR)__\5,FH``$B)WDB-
M/?$,``!)B<0QP.A^Y?__2(7`#X0]`@``28L^2(G&9^CY[/__28G'2(7`#X0E
M`@``3(G__Q5,:@``2(G"@_@#?CQ(F$B)5"0(2(TUZPP``$F-?`?\_Q7;:@``
MA<!U'TB+5"0(@_H$#X2X`P``C4+[2)A!@#P'+P^$J`,``)"+!5IK``"#^/\/
MA&$#``"%P`^$V0$``$B--4X,``!(C3W:"P``,<#H!.G__TB-'<,,``!,C36J
M#```_Q6@:0``4TC'PO____]-B>A03(T-;0L``+X!````3(GG2(T-=`P``#'`
M_Q6.:@``6%KK16:0_Q4B:@``@S@1=4O_%5]I``"#Q0%(@^P(38GH4TR-#2T+
M``!,B?&^`0```%5(Q\+_____3(GG4#'`_Q5):@``2(/$(+[``0``3(GG_Q6'
M:@``@_C_=*I,B>__%3%I``!,B>9(C3W/"@``,<#H4.C__TR)YV?HE_3__^GN
M_?__9I`Q[>D9_?__9@\?A```````2(UL)"#K#68/'X0``````$B#Q0A(BWT`
M2(7_#X21````,<!(B=[HY>/__TB%P'3@@#@`=-M(B<?_%6)I``!)B<5(A<!T
MRNG3^___2(L%KFD``$F+#DV)Z$B-%<$+``"^`0```$B+.#'`_Q4):```Z67]
M__\/'T``2(G'9^C_\___2(N$)$B!``!D2"L$)2@````/A;<"``!(@<18@0``
M2(GO6UU!7$%=05Y!7_\E[F@``+\-````3(TMRPH``/\5[&<``$&X4P```$F)
MQTF)Q.EM^___#Q\`38L^Z=/]___'!79I````````9@\?1```,?9,B?\QP/\5
M8V@``(G#A<`/A!#^__],C;0D0`$``+H"````2,?&[O___XG'_Q7%:```N@8`
M``!,B?:)W_\5;6<``("\)$`!````=0Z`O"1!`0``0P^$F0$``#'2,?:)W_\5
MD6@``+^`````_Q5.9P``9@]O!99(``!(QT`P`````$B)Q0\1`&8/;P602```
MQT!X``````\10!!F#V\%C4@```\10"#K$P\?@`````!,B?9(B>]GZ$3U__^Z
M`(```$R)]HG?_Q7D9@``B<*%P'_>3(V\)"`!``")WTB-G"2X````_Q5^9@``
M2(GN3(G_2(TMR`D``&?HL_;__TR+-"0/'X``````3(GW28/&`D4/M@=(B>E(
MQ\+_____O@$````QP$F#QP'_%=IG``!,.?-UU4B-!<P)``#&A"2X`````%#_
M="0(2(T-B0D``$V)Z$R)YS'`O@$```!,C0UN"```2,?"______\5F6<``%E>
MZ6#]__]F+@\?A```````,<!(B=Y(C3V#"```Z(_A__](A<`/A%;^__\/M@"$
MP`^5PCPP#Y7`#[;`(=")!;YG``#I:/S__TV+=@A-A?8/A$S\__],B??_%4MF
M``!(@_@##X8Y_/__28U\!OQ(C37O"```_Q7?9@``A<!-#T3^Z1S\__^`O"1"
M`0``00^%6?[__X"\)$,!``!##X5+_O__@+PD1`$``$@/A3W^__^`O"1%`0``
M10^%+_[__[H"````2,?&QO___XG?_Q6X9@``NBD```!,B?:)W_\58&4``$B-
M!:\(``!005;IZ/[___\56V8``&9F+@\?A```````\P\>^D%42(T]=@<``%53
M2(/L$$B+';YE``!D2(L$)2@```!(B40D"#'`3(UD)`1,B>9D2(LK#[:%L```
M`(B%L0```#'`Z&;@__](A<!T"8`X,0^$<`$``#'`9^@`Z___9$B+*TB)[[D#
M````N@$```!(C34="```_Q7B9```2(G%2(7`="E(BT`09$B+.TB-%0((``!(
MBS#_%=ID``!(BT402(LP]D8.0`^%40$``&1(BSNY`P```+H!````2(TUV`<`
M`/\5EF0``$B)Q4B%P'0N3(GF2(T]=08``#'`Z,W?__](B<)(A<`/A/$```!(
MBT409$B+.TB+,/\5>&0``&1(BSNZ`0```$B--8X'``#_%=)C``!D2(L[2(T5
MD@<``$B)QO\53F0``&1(BP-,B>9(C3T0!@``QH"Q`````#'`Z&K?__](B07S
M90``2(G#2(7`=$.^P`$``$B)W_\5A64``(U0`8/Z`78)@_@1#X6;````2(M$
M)`AD2"L$)2@````/A:4```!(@\006UU!7,,/'X``````2(L]J64``&?HZ_7_
M_TB)!91E``!(B<-(A<!UH4B-/9T'```QP/\5M60```\?1```@'@!``^$DO[_
M_^F!_O__9@\?A```````2(L%864``$B+,$B+11!(BSCH^N'__^D%____#Q]$
M``!D2(L[_Q4^9```Z:#^__^)P4B+!3!E``!(B=I(C3U>!P``2(LP,<#_%4MD
M``#_%1UD``!F+@\?A```````#Q\`\P\>^DB+#:UD``#_)>=B``````#S#Q[Z
M2(/L"$B#Q`C#````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R]S96QF+V5X90`O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`$Q$7TQ)0E)!4EE?4$%42`!P87(M`"UE
M`"TM`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315(`55-%4DY!344`)3`R
M>``E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M
M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI6
M15)324].`#$N,#4U```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I
M;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H
M;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D
M978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL
M96YA;65=*3L*?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q
M6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D[
M"F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI
M.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\
M.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F
M:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET
M(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@7T9(.PIM
M>2`D;6%G:6-?<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`C
M($Y/5$4Z("1M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?
M<&]S+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H
M)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G
M:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?<&]S(#P@,"D@
M>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#
M(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B
M1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*
M;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@
M9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@-"`M("1O9F9S970L(#`["B1D871A7W!O<R`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL
M96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I
M.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L
M94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R
M8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE
M>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I
M;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F
M:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^
M<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D[
M"B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M
M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IU;FQE<W,@*"1B=68@
M97$@(E!+7#`P,UPP,#0B*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R
M($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'
M24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@
M("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]
M"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF
M="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z
M.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@
M)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z
M("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O
M<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A
M9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I
M;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T
M85]P;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E
M('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^
M<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R
M('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"
M4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO
M)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R
M($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,[
M"FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@
M("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@
M)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I
M.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@
M/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=
M*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@
M(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I
M.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE
M>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@
M86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F
M*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M
M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE
M*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@
M)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H
M/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@
M;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV
M93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U
M=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD
M>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O
M=70B73L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O
M=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E
M;B!M>2`D=&@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)'1H*3L*
M8VQO<V4@)'1H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*#0P("T@;&5N9W1H("1C86-H95]N86UE
M*3L*)&-A8VAE7VYA;64@+CT@(EPP0T%#2$4B.PIM>2`D;V9F<V5T(#T@)&9H
M+3YT96QL("L@;&5N9W1H*"1C86-H95]N86UE*2`M(&QE;F=T:"@D;&]A9&5R
M*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*<&%C:R@G3B<L("1O9F9S970I
M+`HD4$%27TU!1TE#*0HF)B`D9F@M/F-L;W-E"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O
M=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R
M871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I
M+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*;W5T<R@B4F5A9&EN9R!-151!+GEM;"XN+B(I
M.PII9B`H;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PHD;65T82`]?B!S+RXJ7G!A<CI<<RHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["FEF("AM>2`H)&-L96%N*2`]("1M971A(#U^("]>7',K8VQE86XZ
M("@N*BDD+VTI('L*)&-L96%N(#U^("]>7',J?%QS*B0O9SL*)$5.5GM005)?
M0TQ%04Y](#T@,2!I9B`D8VQE86X["GT*?0IP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T
M<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M
M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI
M;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D
M8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU
M."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D<WES>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*
M;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M
M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D<WES>U]D
M96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]
M=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P``````````````
M`````/____\`````_____P`````!(T5G`````(FKS>\`````_MRZF`````!V
M5#(0`````/#ATL,````````````````!&P,[W````!H```!`@/__Z`0``'""
M___X````<(/__Q`!``#@F?__8`$``+":__^L`0``0)O__]`!``#`G/__#`(`
M`""=__\H`@```)[__V@"``!0H/__M`(``("@___(`@``8*'___P"``!PH?__
M$`,``("C__]T`P``L*/__X@#``"0I/__L`,``*"I___\`P``(*K__Q@$``!0
MJO__,`0``&"K__^,!```L*O__Z0$``#`K/__%`4``'"N__]@!0``P+#__Z`%
M```PN?__>`8``'"[__^P!@```````!0``````````7I2``%X$`$;#`<(D`$`
M`!0````<````<('__R8`````1`<0`````$P````T````6(+__VL6````0@X0
MCP))#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1P[0!0-"%@H..$$.,$$.*$(.
M($(.&$(.$$(."$$+````2````(0```!XF/__S`````!"#A"/`D(.&(X#0@X@
MC01"#BB,!4$.,(8&00XX@P=$#D`";0H..$0.,$$.*$(.($(.&$(.$$(."$@+
M`"````#0````_)C__X0`````00X0@P)*#K`!`G$*#A!!#@A!"S@```#T````
M:)G__WT!````0@X0C0)"#AB,`T$.((8$00XH@P5'#M`!?@H.*$$.($$.&$(.
M$$(."$<+`!@````P`0``K)K__U$`````10X0@P("1@X(```\````3`$``/":
M___;`````$(.$(T"0@X8C`-!#B"&!$$.*(,%1PZH($D.P"`">`H.*$$.($$.
M&$(.$$(."$0+2````(P!``"0F___0@(```!"#A"/`D(.&(X#0@X@C01"#BB,
M!4$.,(8&1`XX@P='#F`#'0$*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"Q````#8
M`0``E)W__RH`````````,````.P!``"PG?__V`````!%#A"&`D$.&(,#1PZ8
M($P.F$!)#L!``J8*#AA$#A!!#@A!"Q`````@`@``7)[__PH`````````8```
M`#0"``!8GO__!0(```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='
M#K@@3`[P(0)R"@XX00XP00XH0@X@0@X80@X00@X(0PL"I0[X(4D.@")?#O@A
M00[P(0```!````"8`@``!*#__R4`````````)````*P"```@H/__U0````!.
M#A"#`@*,"@X(1@M("L,."$@+3<,."$@```#4`@``V*#__P4%````1@X0CP)"
M#AB.`T(.((T$0@XHC`5!#C"&!D@..(,'1`Y0`Z8$"@XX30XP00XH0@X@0@X8
M0@X00@X(10L8````(`,``)RE__]]`````$@.(&T*#@A+"P``%````#P#````
MIO__(P````!(#A!:#@@`6````%0#```8IO__$`$```!&#A"-`D(.&(P#2`X@
MA@1'#BB#!40.0`)""@XH1@X@00X80@X00@X(2`ME"@XH00X@00X80@X00@X(
M10MD#DA)#E!D#DA!#D`````4````L`,``,RF__]*`````$@.$`)!#@A`````
MR`,```2G__\.`0```$8.$(P"00X8A@-$#B"#!$0.,`)J"@X@00X800X00@X(
M0PMS"@X@1`X800X00@X(1@L``"@````,!```4'O__R("````10X0A@)!#AB#
M`T0.4`-W`0H.&$,.$$$."$$+2````#@$``"DI___IP$```!&#A"/`D4.&(X#
M10X@C01"#BB,!40.,(8&10XX@P='#D`"X0H..$$.,$$.*$(.($(.&$(.$$(.
M"$,+`#P```"$!```"*G__TL"````1@X0C@)&#AB-`T(.((P$00XHA@5$#C"#
M!@.;`0H.*$$.($(.&$(.$$(."$L+``#4````Q`0``!BK__]E"````$8.$(\"
M0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T@,"[B``E$-!T<.D(,"`QT"#IB#
M`F$.H(,"80Z8@P)"#I"#`@)["@XX1`XP00XH0@X@0@X80@X00@X(20L#,0$.
MF(,"2PZ@@P)?#IB#`D$.D(,"7`Z8@P)$#J"#`E`.J(,"2PZP@P),#I"#`@+L
M"@XX1`XP00XH0@X@0@X80@X00@X(1@L#@0$.F(,"1`Z@@P)I#IB#`D$.D(,"
M`N<*#IB#`D(.H(,"10LT````G`4``+"R__\S`@```$8.$(P"2`X8A@-!#B"#
M!$0.,`-Y`0H.($$.&$$.$$(."$@+`````!````#4!0``N+3__Q$`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!`(P```````/`B`````````0````````#9`@``````
M``$`````````Y`(````````/`````````&4$````````#```````````(```
M``````T`````````9%L````````9`````````/B[````````&P`````````(
M`````````!H``````````+P````````<``````````@`````````]?[_;P``
M``#0`P````````4`````````R`T````````&`````````!`%````````"@``
M``````"(!`````````L`````````&``````````5````````````````````
M!P````````"0$P````````@`````````D`8````````)`````````!@`````
M````&````````````````````/O__V\``````0``"`````#^__]O`````!`3
M````````____;P`````!`````````/#__V\`````4!(```````#Y__]O````
M``0`````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````(
MO```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#88@```````$=#
M0SH@*$=.52D@,3(N,2XP```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;&$N9'EN`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````````
M````````````````````````````````````````````````````````````
M```````````````+`````0````(`````````&`,````````8`P```````!P`
M```````````````````!````````````````````$P````<````"````````
M`#@#````````.`,```````!0````````````````````"```````````````
M`````"8````'`````@````````"(`P```````(@#````````)```````````
M``````````0````````````````````Y````!P````(`````````K`,`````
M``"L`P```````"`````````````````````$````````````````````1P``
M`/;__V\"`````````-`#````````T`,```````!``0````````8`````````
M"````````````````````%$````+`````@`````````0!0```````!`%````
M````N`@````````'`````0````@`````````&`````````!9`````P````(`
M````````R`T```````#(#0```````(@$```````````````````!````````
M````````````80```/___V\"`````````%`2````````4!(```````"Z````
M``````8``````````@`````````"`````````&X```#^__]O`@`````````0
M$P```````!`3````````@``````````'`````0````@`````````````````
M``!]````!`````(`````````D!,```````"0$P```````)`&````````!@``
M```````(`````````!@`````````AP````$````&```````````@````````
M`"`````````;````````````````````!````````````````````(T````!
M````!@`````````@(````````"`@````````03L``````````````````!``
M``````````````````"3`````0````8`````````9%L```````!D6P``````
M``T````````````````````$````````````````````F0````$````"````
M``````!@`````````&````````#@/P``````````````````$```````````
M`````````*$````!`````@````````#@GP```````."?````````W```````
M``````````````0```````````````````"O`````0````(`````````P*``
M``````#`H````````.@%```````````````````(````````````````````
MN0````X````#`````````/B[````````^*L````````(````````````````
M````"``````````(`````````,4````/`````P``````````O`````````"L
M````````"`````````````````````@`````````"`````````#1````!@``
M``,`````````"+P````````(K````````-`!````````!P`````````(````
M`````!``````````V@````$````#`````````-B]````````V*T````````H
M`@``````````````````"``````````(`````````-\````!`````P``````
M````P`````````"P````````(`````````````````````@`````````````
M``````#E````"`````,`````````(,`````````@L````````$`0````````
M```````````@````````````````````Z@````$````P````````````````
M````(+`````````2`````````````````````0`````````!``````````$`
M```#`````````````````````````#*P````````\P``````````````````
1``$`````````````````````
